"""openplaces - A package for working with geospatial property data."""

__version__ = "0.1.0"
__author__ = "Christoph Nolte, openplaces Consortium"
__email__ = "nolte.christoph@gmail.com"

from .main import *


"""Main module for openplaces package."""

def hello_openplaces():
    """A simple hello function."""
    return "Hello from `openplaces`!"

def get_version():
    """Return the package version."""
    from . import __version__
    return __version__